DROP VIEW IF EXISTS suser_attr_changes_v;
DROP VIEW IF EXISTS suser_all_v;
DROP VIEW IF EXISTS suser_v;

CREATE VIEW suser_v AS 
SELECT
    suser.id,
    suser.deleted,
    suser.department,
    suser.display_description,
    suser.display_name,
    suser.dn,
    suser.effective,
    suser.employee_status,
    suser.employee_type,
    suser.first_name,
    suser.full_name,
    suser.guid,
    suser.home_phone,
    suser.idm_dn,
    suser.idm_tree_name,
    suser.is_curated,
    suser.job_code,
    suser.job_title,
    suser.last_name,
    suser.location,
    suser.merged,
    suser.middle_name,
    suser.office_phone,
    suser.other_phone,
    suser.preferred_locale,
    suser.provisioning_id,
    suser.secondary_supervisor_id,
    suser.supervisor_attr_key,
    suser.supervisor_id,
    suser.supervisor_unique_id,
    suser.unique_user_id,
    suser.user_id,
    suser.business_unit,
    suser.collected_entity,
    suser.effective_entity,
    suser.identity_source,
    suser.sversion,
    suser.workforce_id,
    suser_email.email,
    suser.risk
FROM suser
    LEFT JOIN 
        (SELECT
            suser.id suser,
            suser.display_name,
            string_agg(suser_email.email, ' | ' order by suser_email.email) As email
        FROM suser
        JOIN suser_email ON suser.id = suser_email.suser AND suser.effective = '1' AND suser.deleted = '0'   
        GROUP BY suser.id, suser.display_name) suser_email ON suser.id = suser_email.suser
WHERE suser.deleted = '0' AND suser.effective = '1';

CREATE VIEW suser_all_v AS 
  SELECT
    suser.id,
    suser.deleted,
    suser.department,
    suser.display_description,
    suser.display_name,
    suser.dn,
    suser.effective,
    suser.employee_status,
    suser.employee_type,
    suser.first_name,
    suser.full_name,
    suser.guid,
    suser.home_phone,
    suser.idm_dn,
    suser.idm_tree_name,
    suser.is_curated,
    suser.job_code,
    suser.job_title,
    suser.last_name,
    suser.location,
    suser.merged,
    suser.middle_name,
    suser.office_phone,
    suser.other_phone,
    suser.preferred_locale,
    suser.provisioning_id,
    suser.secondary_supervisor_id,
    suser.supervisor_attr_key,
    suser.supervisor_id,
    suser.supervisor_unique_id,
    suser.unique_user_id,
    suser.user_id,
    suser.business_unit,
    suser.collected_entity,
    suser.effective_entity,
    suser.identity_source,
    suser.sversion,
    suser.workforce_id,
    suser_email.email,
    suser.risk
FROM suser
  LEFT JOIN (
    SELECT
      suser.id suser,
      suser.display_name,
      string_agg(suser_email.email, ' | ' order by suser_email.email) As email
    FROM suser
      JOIN suser_email ON suser.id = suser_email.suser AND suser.effective = '1' AND suser.deleted = '0'   
    GROUP BY suser.id, suser.display_name) suser_email ON suser.id = suser_email.suser;

CREATE VIEW suser_attr_changes_v AS 
SELECT 
    su.first_name,
    su.middle_name,
    su.last_name,
    su.office_phone,
    min(sv."timestamp") AS "timestamp",
    su.home_phone,
    su.other_phone,
    su.department,
    su.job_title,
    semail.email,
    su.display_description,
    su.employee_status,
    su.employee_type,
    su.location,
    su.preferred_locale,
    su.supervisor_unique_id,
    supervisor.display_name as supervisor_display_name,
    supervisor.workforce_id as supervisor_workforce_id,
    su.workforce_id,
    su.risk,
    min(su.sversion) AS sversion,
    su.unique_user_id
   FROM suser su
   LEFT JOIN suser supervisor ON supervisor.workforce_id = su.supervisor_id
     JOIN sversion sv ON su.sversion = sv.id AND su.deleted = false AND su.collected_entity = su.effective_entity
     LEFT JOIN ( SELECT su2.id AS suser_id,
            string_agg(semail2.email::text, ' | '::text ORDER BY (semail2.email::text)) AS email
           FROM suser su2
             JOIN suser_email semail2 ON su2.id = semail2.suser AND su2.is_curated = false AND su2.deleted = false
          GROUP BY su2.id) semail ON semail.suser_id = su.id
  GROUP BY su.first_name, su.middle_name, su.last_name, su.office_phone, su.home_phone, su.other_phone, su.department, su.job_title, semail.email, su.display_description, su.employee_status, su.employee_type, su.location, su.preferred_locale, su.supervisor_unique_id, supervisor.display_name, supervisor.workforce_id, su.workforce_id, su.risk, su.unique_user_id;
  
ALTER TABLE suser_v
  OWNER TO igops;
GRANT ALL ON TABLE suser_v TO igops;
GRANT SELECT ON TABLE suser_v TO ig_report_role;

ALTER TABLE suser_all_v
  OWNER TO igops;
GRANT ALL ON TABLE suser_all_v TO igops;
GRANT SELECT ON TABLE suser_all_v TO ig_report_role;

ALTER TABLE suser_attr_changes_v
  OWNER TO igops;
GRANT ALL ON TABLE suser_attr_changes_v TO igops;
GRANT SELECT ON TABLE suser_attr_changes_v TO ig_report_role;